
From: Adrian Bunk <bunk@stusta.de>

The second arg of do_timer_interrupt() is not used in the functions, and
all callers pass NULL.

Signed-off-by: Adrian Bunk <bunk@stusta.de>
Cc: Paul Mundt <lethal@Linux-SH.ORG>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 arch/i386/kernel/time.c |    5 ++---
 arch/sh/kernel/time.c   |    4 ++--
 arch/sh64/kernel/time.c |    4 ++--
 3 files changed, 6 insertions(+), 7 deletions(-)

diff -puN arch/i386/kernel/time.c~remove-the-second-arg-of-do_timer_interrupt arch/i386/kernel/time.c
--- devel/arch/i386/kernel/time.c~remove-the-second-arg-of-do_timer_interrupt	2005-08-21 21:57:57.000000000 -0700
+++ devel-akpm/arch/i386/kernel/time.c	2005-08-21 21:57:57.000000000 -0700
@@ -252,8 +252,7 @@ EXPORT_SYMBOL(profile_pc);
  * timer_interrupt() needs to keep up the real-time clock,
  * as well as call the "do_timer()" routine every clocktick
  */
-static inline void do_timer_interrupt(int irq, void *dev_id,
-					struct pt_regs *regs)
+static inline void do_timer_interrupt(int irq, struct pt_regs *regs)
 {
 #ifdef CONFIG_X86_IO_APIC
 	if (timer_ack) {
@@ -307,7 +306,7 @@ irqreturn_t timer_interrupt(int irq, voi
 
 	cur_timer->mark_offset();
  
-	do_timer_interrupt(irq, NULL, regs);
+	do_timer_interrupt(irq, regs);
 
 	write_sequnlock(&xtime_lock);
 	return IRQ_HANDLED;
diff -puN arch/sh64/kernel/time.c~remove-the-second-arg-of-do_timer_interrupt arch/sh64/kernel/time.c
--- devel/arch/sh64/kernel/time.c~remove-the-second-arg-of-do_timer_interrupt	2005-08-21 21:57:57.000000000 -0700
+++ devel-akpm/arch/sh64/kernel/time.c	2005-08-21 21:57:57.000000000 -0700
@@ -303,7 +303,7 @@ static long last_rtc_update = 0;
  * timer_interrupt() needs to keep up the real-time clock,
  * as well as call the "do_timer()" routine every clocktick
  */
-static inline void do_timer_interrupt(int irq, void *dev_id, struct pt_regs *regs)
+static inline void do_timer_interrupt(int irq, struct pt_regs *regs)
 {
 	unsigned long long current_ctc;
 	asm ("getcon cr62, %0" : "=r" (current_ctc));
@@ -361,7 +361,7 @@ static irqreturn_t timer_interrupt(int i
 	 * locally disabled. -arca
 	 */
 	write_lock(&xtime_lock);
-	do_timer_interrupt(irq, NULL, regs);
+	do_timer_interrupt(irq, regs);
 	write_unlock(&xtime_lock);
 
 	return IRQ_HANDLED;
diff -puN arch/sh/kernel/time.c~remove-the-second-arg-of-do_timer_interrupt arch/sh/kernel/time.c
--- devel/arch/sh/kernel/time.c~remove-the-second-arg-of-do_timer_interrupt	2005-08-21 21:57:57.000000000 -0700
+++ devel-akpm/arch/sh/kernel/time.c	2005-08-21 21:57:57.000000000 -0700
@@ -234,7 +234,7 @@ static long last_rtc_update;
  * timer_interrupt() needs to keep up the real-time clock,
  * as well as call the "do_timer()" routine every clocktick
  */
-static inline void do_timer_interrupt(int irq, void *dev_id, struct pt_regs *regs)
+static inline void do_timer_interrupt(int irq, struct pt_regs *regs)
 {
 	do_timer(regs);
 #ifndef CONFIG_SMP
@@ -285,7 +285,7 @@ static irqreturn_t timer_interrupt(int i
 	 * locally disabled. -arca
 	 */
 	write_seqlock(&xtime_lock);
-	do_timer_interrupt(irq, NULL, regs);
+	do_timer_interrupt(irq, regs);
 	write_sequnlock(&xtime_lock);
 
 	return IRQ_HANDLED;
_
